==> haskell-haddock-api-2.17.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-api.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-api
version: 2.17.3
id: haddock-api-2.17.3-6ujLs1CbFYa7jrMQNMWDcD
key: haddock-api-2.17.3-6ujLs1CbFYa7jrMQNMWDcD
license: BSD3
copyright: (c) Simon Marlow, David Waern
maintainer: Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
stability: experimental
homepage: http://www.haskell.org/haddock/
synopsis: A documentation-generation tool for Haskell libraries
description:
    Haddock is a documentation-generation tool for Haskell
    libraries
category: Documentation
author: Simon Marlow, David Waern
exposed: True
exposed-modules:
    Documentation.Haddock
hidden-modules: Haddock Haddock.Interface Haddock.Interface.Rename
                Haddock.Interface.Create Haddock.Interface.AttachInstances
                Haddock.Interface.LexParseRn Haddock.Interface.ParseModuleHeader
                Haddock.Interface.Specialize Haddock.Parser Haddock.Utils
                Haddock.Backends.Xhtml Haddock.Backends.Xhtml.Decl
                Haddock.Backends.Xhtml.DocMarkup Haddock.Backends.Xhtml.Layout
                Haddock.Backends.Xhtml.Names Haddock.Backends.Xhtml.Themes
                Haddock.Backends.Xhtml.Types Haddock.Backends.Xhtml.Utils
                Haddock.Backends.LaTeX Haddock.Backends.HaddockDB
                Haddock.Backends.Hoogle Haddock.Backends.Hyperlinker
                Haddock.Backends.Hyperlinker.Ast
                Haddock.Backends.Hyperlinker.Parser
                Haddock.Backends.Hyperlinker.Renderer
                Haddock.Backends.Hyperlinker.Types
                Haddock.Backends.Hyperlinker.Utils Haddock.ModuleTree Haddock.Types
                Haddock.Doc Haddock.Version Haddock.InterfaceFile Haddock.Options
                Haddock.GhcUtils Haddock.Syb Haddock.Convert Paths_haddock_api
abi: a1694c8ad1b11597ee0b9f7e623d28dd
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-api-2.17.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-api-2.17.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/haddock-api-2.17.3
hs-libraries: HShaddock-api-2.17.3-6ujLs1CbFYa7jrMQNMWDcD
depends:
    Cabal-1.24.0.0 array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 directory-1.2.6.2
    filepath-1.4.1.0 ghc-8.0.1 ghc-boot-8.0.1
    ghc-paths-0.1.0.9-GIOnKzk0HmEBZ77Q1HsThK
    haddock-library-1.4.2-F7UTHpERtmTC4fYnmJsN6z transformers-0.5.2.0
    xhtml-3000.2.1
haddock-interfaces: /usr/share/doc/haskell-haddock-api/html/haddock-api.haddock
haddock-html: /usr/share/doc/haskell-haddock-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-haddock-api-2.17.3.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-api.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-api
version: 2.17.3.1
id: haddock-api-2.17.3.1-2MrO59fMQWm4VgpmbTQ9ee
key: haddock-api-2.17.3.1-2MrO59fMQWm4VgpmbTQ9ee
license: BSD3
copyright: (c) Simon Marlow, David Waern
maintainer: Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
stability: experimental
homepage: http://www.haskell.org/haddock/
synopsis: A documentation-generation tool for Haskell libraries
description:
    Haddock is a documentation-generation tool for Haskell
    libraries
category: Documentation
author: Simon Marlow, David Waern
exposed: True
exposed-modules:
    Documentation.Haddock
hidden-modules: Haddock Haddock.Interface Haddock.Interface.Rename
                Haddock.Interface.Create Haddock.Interface.AttachInstances
                Haddock.Interface.LexParseRn Haddock.Interface.ParseModuleHeader
                Haddock.Interface.Specialize Haddock.Parser Haddock.Utils
                Haddock.Backends.Xhtml Haddock.Backends.Xhtml.Decl
                Haddock.Backends.Xhtml.DocMarkup Haddock.Backends.Xhtml.Layout
                Haddock.Backends.Xhtml.Names Haddock.Backends.Xhtml.Themes
                Haddock.Backends.Xhtml.Types Haddock.Backends.Xhtml.Utils
                Haddock.Backends.LaTeX Haddock.Backends.HaddockDB
                Haddock.Backends.Hoogle Haddock.Backends.Hyperlinker
                Haddock.Backends.Hyperlinker.Ast
                Haddock.Backends.Hyperlinker.Parser
                Haddock.Backends.Hyperlinker.Renderer
                Haddock.Backends.Hyperlinker.Types
                Haddock.Backends.Hyperlinker.Utils Haddock.ModuleTree Haddock.Types
                Haddock.Doc Haddock.Version Haddock.InterfaceFile Haddock.Options
                Haddock.GhcUtils Haddock.Syb Haddock.Convert Paths_haddock_api
abi: 5b94ead611e1862fc7a3fd519c950975
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-api-2.17.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/haddock-api-2.17.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/haddock-api-2.17.3.1
hs-libraries: HShaddock-api-2.17.3.1-2MrO59fMQWm4VgpmbTQ9ee
depends:
    Cabal-1.24.0.0 array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 directory-1.2.6.2
    filepath-1.4.1.0 ghc-8.0.1 ghc-boot-8.0.1
    ghc-paths-0.1.0.9-GIOnKzk0HmEBZ77Q1HsThK
    haddock-library-1.4.2-F7UTHpERtmTC4fYnmJsN6z transformers-0.5.2.0
    xhtml-3000.2.1
haddock-interfaces: /usr/share/doc/haskell-haddock-api/html/haddock-api.haddock
haddock-html: /usr/share/doc/haskell-haddock-api/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
